@@ -5,7 +5,7 @@ class BaseFrontMatterProcessor(object):
         """
         pass
 
-    def process(self, posts):
+    def process(self, posts, allow_overwrite):
         """Process a list of posts and update their front matters.
         """
         pass
